==> eff-writer_3-7.0.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"writer","t":"writer","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/writer$.html#","e":false,"i":"","n":"writer","t":"writer extends writer","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/writer.html#","e":false,"i":"","n":"writer","t":"writer","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/writer.html#WriterEffectOps-b0b","e":false,"i":"","n":"WriterEffectOps","t":"WriterEffectOps[R, A](e: Eff[R, A]): WriterEffectOps[R, A]","d":"org.atnos.eff.syntax.writer","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#","e":false,"i":"","n":"WriterEffectOps","t":"WriterEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.writer","k":"class","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#discardWriter-fd5","e":false,"i":"","n":"discardWriter","t":"discardWriter[O, U](implicit member: Aux[[_] =>> Writer[O, _$7], R, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriter-fffff336","e":false,"i":"","n":"runWriter","t":"runWriter[O](implicit member: Member[[_] =>> Writer[O, _$1], R]): Eff[member.Out, (A, List[O])]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterEval-5e7","e":false,"i":"","n":"runWriterEval","t":"runWriterEval[O, U](f: O => Eval[Unit])(implicit member: Aux[[_] =>> Writer[O, _$14], R, U], v: MemberIn[Eval, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterFold-fffff17e","e":false,"i":"","n":"runWriterFold","t":"runWriterFold[O, B](fold: RightFold[O, B])(implicit member: Member[[_] =>> Writer[O, _$10], R]): Eff[member.Out, (A, B)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterIntoMonoid-fffff52a","e":false,"i":"","n":"runWriterIntoMonoid","t":"runWriterIntoMonoid[O, M](f: O => M)(implicit member: Member[[_] =>> Writer[O, _$12], R], M: Monoid[M]): Eff[member.Out, (A, M)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterLog-fffff336","e":false,"i":"","n":"runWriterLog","t":"runWriterLog[O](implicit member: Member[[_] =>> Writer[O, _$8], R]): Eff[member.Out, List[O]]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterMonoid-fffff2d8","e":false,"i":"","n":"runWriterMonoid","t":"runWriterMonoid[B](implicit member: Member[[_] =>> Writer[B, _$11], R], B: Monoid[B]): Eff[member.Out, (A, B)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterNoLog-fffff336","e":false,"i":"","n":"runWriterNoLog","t":"runWriterNoLog[O](implicit member: Member[[_] =>> Writer[O, _$3], R]): Eff[member.Out, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterNoLogU-fd5","e":false,"i":"","n":"runWriterNoLogU","t":"runWriterNoLogU[O, U](implicit member: Aux[[_] =>> Writer[O, _$5], R, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterU-fd5","e":false,"i":"","n":"runWriterU","t":"runWriterU[O, U](implicit member: Aux[[_] =>> Writer[O, _$2], R, U]): Eff[U, (A, List[O])]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterUnsafe-487","e":false,"i":"","n":"runWriterUnsafe","t":"runWriterUnsafe[O](f: O => Unit)(implicit member: Member[[_] =>> Writer[O, _$13], R]): Eff[member.Out, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#","e":false,"i":"","n":"RightFold","t":"RightFold[A, B]","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/RightFold.html#S-0","e":false,"i":"","n":"S","t":"S","d":"org.atnos.eff.RightFold","k":"type","x":""},
{"l":"org/atnos/eff/RightFold.html#finalize-d26","e":false,"i":"","n":"finalize","t":"finalize(s: S): B","d":"org.atnos.eff.RightFold","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#fold-fffffab9","e":false,"i":"","n":"fold","t":"fold(a: A, s: S): S","d":"org.atnos.eff.RightFold","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#init-0","e":false,"i":"","n":"init","t":"init: S","d":"org.atnos.eff.RightFold","k":"val","x":""},
{"l":"org/atnos/eff/WriterCreation.html#","e":false,"i":"","n":"WriterCreation","t":"WriterCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterCreation.html#tell-7bd","e":false,"i":"","n":"tell","t":"tell[R, O](o: O)(implicit member: MemberIn[[_] =>> Writer[O, _$1], R]): Eff[R, Unit]","d":"org.atnos.eff.WriterCreation","k":"def","x":""},
{"l":"org/atnos/eff/WriterCreation$.html#","e":false,"i":"","n":"WriterCreation","t":"WriterCreation extends WriterCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/WriterEffect.html#","e":false,"i":"","n":"WriterEffect","t":"WriterEffect extends WriterCreation, WriterInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterEffect$.html#","e":false,"i":"","n":"WriterEffect","t":"WriterEffect extends WriterEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#","e":false,"i":"","n":"WriterInterpretation","t":"WriterInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#EvalFold-91b","e":false,"i":"","n":"EvalFold","t":"EvalFold[A](f: A => Eval[Unit]): RightFold[A, Eval[Unit]]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#IntoMonoidFold-6fe","e":false,"i":"","n":"IntoMonoidFold","t":"IntoMonoidFold[M : Monoid, A](f: A => M): RightFold[A, M]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#ListFold-fffff60a","e":false,"i":"","n":"ListFold","t":"ListFold[A]: RightFold[A, List[A]]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#MonoidFold-fffffd2c","e":false,"i":"","n":"MonoidFold","t":"MonoidFold[A : Monoid]: RightFold[A, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriter-fffff599","e":false,"i":"","n":"runWriter","t":"runWriter[R, U, O, A, B](w: Eff[R, A])(implicit m: Aux[[_] =>> Writer[O, _$1], R, U]): Eff[U, (A, List[O])]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterEval-b44","e":false,"i":"","n":"runWriterEval","t":"runWriterEval[R, U, O, A](w: Eff[R, A])(f: O => Eval[Unit])(implicit m: Aux[[_] =>> Writer[O, _$8], R, U], ev: MemberIn[Eval, U]): Eff[U, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterFold-ffffff3a","e":false,"i":"","n":"runWriterFold","t":"runWriterFold[R, U, O, A, B](w: Eff[R, A])(fold: RightFold[O, B])(implicit m: Aux[[_] =>> Writer[O, _$2], R, U]): Eff[U, (A, B)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterIntoMonoid-fffff7e6","e":false,"i":"","n":"runWriterIntoMonoid","t":"runWriterIntoMonoid[R, U, O, M, A](w: Eff[R, A])(f: O => M)(implicit m: Aux[[_] =>> Writer[O, _$10], R, U], M: Monoid[M]): Eff[U, (A, M)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterMonoid-b7a","e":false,"i":"","n":"runWriterMonoid","t":"runWriterMonoid[R, U, O, A](w: Eff[R, A])(implicit m: Aux[[_] =>> Writer[O, _$9], R, U], O: Monoid[O]): Eff[U, (A, O)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterUnsafe-ffffff25","e":false,"i":"","n":"runWriterUnsafe","t":"runWriterUnsafe[R, U, O, A](w: Eff[R, A])(f: O => Unit)(implicit m: Aux[[_] =>> Writer[O, _$5], R, U]): Eff[U, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation$.html#","e":false,"i":"","n":"WriterInterpretation","t":"WriterInterpretation extends WriterInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/writer$.html#","e":false,"i":"","n":"writer","t":"writer extends WriterCreation, WriterInterpretation","d":"org.atnos.eff","k":"object","x":""}];

==> eff-writer_3-7.0.6-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"writer","t":"writer","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/writer$.html#","e":false,"i":"","n":"writer","t":"writer extends writer","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/writer.html#","e":false,"i":"","n":"writer","t":"writer","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/syntax/writer.html#WriterEffectOps-b0b","e":false,"i":"","n":"WriterEffectOps","t":"WriterEffectOps[R, A](e: Eff[R, A]): WriterEffectOps[R, A]","d":"org.atnos.eff.syntax.writer","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#","e":false,"i":"","n":"WriterEffectOps","t":"WriterEffectOps[R, A](e: Eff[R, A])","d":"org.atnos.eff.syntax.writer","k":"class","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#discardWriter-fd5","e":false,"i":"","n":"discardWriter","t":"discardWriter[O, U](implicit member: Aux[[_] =>> Writer[O, _$7], R, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriter-fffff336","e":false,"i":"","n":"runWriter","t":"runWriter[O](implicit member: Member[[_] =>> Writer[O, _$1], R]): Eff[member.Out, (A, List[O])]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterEval-5e7","e":false,"i":"","n":"runWriterEval","t":"runWriterEval[O, U](f: O => Eval[Unit])(implicit member: Aux[[_] =>> Writer[O, _$14], R, U], v: MemberIn[Eval, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterFold-fffff17e","e":false,"i":"","n":"runWriterFold","t":"runWriterFold[O, B](fold: RightFold[O, B])(implicit member: Member[[_] =>> Writer[O, _$10], R]): Eff[member.Out, (A, B)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterIntoMonoid-fffff52a","e":false,"i":"","n":"runWriterIntoMonoid","t":"runWriterIntoMonoid[O, M](f: O => M)(implicit member: Member[[_] =>> Writer[O, _$12], R], M: Monoid[M]): Eff[member.Out, (A, M)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterLog-fffff336","e":false,"i":"","n":"runWriterLog","t":"runWriterLog[O](implicit member: Member[[_] =>> Writer[O, _$8], R]): Eff[member.Out, List[O]]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterMonoid-fffff2d8","e":false,"i":"","n":"runWriterMonoid","t":"runWriterMonoid[B](implicit member: Member[[_] =>> Writer[B, _$11], R], B: Monoid[B]): Eff[member.Out, (A, B)]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterNoLog-fffff336","e":false,"i":"","n":"runWriterNoLog","t":"runWriterNoLog[O](implicit member: Member[[_] =>> Writer[O, _$3], R]): Eff[member.Out, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterNoLogU-fd5","e":false,"i":"","n":"runWriterNoLogU","t":"runWriterNoLogU[O, U](implicit member: Aux[[_] =>> Writer[O, _$5], R, U]): Eff[U, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterU-fd5","e":false,"i":"","n":"runWriterU","t":"runWriterU[O, U](implicit member: Aux[[_] =>> Writer[O, _$2], R, U]): Eff[U, (A, List[O])]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/syntax/writer$WriterEffectOps.html#runWriterUnsafe-487","e":false,"i":"","n":"runWriterUnsafe","t":"runWriterUnsafe[O](f: O => Unit)(implicit member: Member[[_] =>> Writer[O, _$13], R]): Eff[member.Out, A]","d":"org.atnos.eff.syntax.writer.WriterEffectOps","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#","e":false,"i":"","n":"RightFold","t":"RightFold[A, B]","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/RightFold.html#S-0","e":false,"i":"","n":"S","t":"S","d":"org.atnos.eff.RightFold","k":"type","x":""},
{"l":"org/atnos/eff/RightFold.html#finalize-d26","e":false,"i":"","n":"finalize","t":"finalize(s: S): B","d":"org.atnos.eff.RightFold","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#fold-fffffab9","e":false,"i":"","n":"fold","t":"fold(a: A, s: S): S","d":"org.atnos.eff.RightFold","k":"def","x":""},
{"l":"org/atnos/eff/RightFold.html#init-0","e":false,"i":"","n":"init","t":"init: S","d":"org.atnos.eff.RightFold","k":"val","x":""},
{"l":"org/atnos/eff/WriterCreation.html#","e":false,"i":"","n":"WriterCreation","t":"WriterCreation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterCreation.html#tell-7bd","e":false,"i":"","n":"tell","t":"tell[R, O](o: O)(implicit member: MemberIn[[_] =>> Writer[O, _$1], R]): Eff[R, Unit]","d":"org.atnos.eff.WriterCreation","k":"def","x":""},
{"l":"org/atnos/eff/WriterCreation$.html#","e":false,"i":"","n":"WriterCreation","t":"WriterCreation extends WriterCreation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/WriterEffect.html#","e":false,"i":"","n":"WriterEffect","t":"WriterEffect extends WriterCreation, WriterInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterEffect$.html#","e":false,"i":"","n":"WriterEffect","t":"WriterEffect extends WriterEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#","e":false,"i":"","n":"WriterInterpretation","t":"WriterInterpretation","d":"org.atnos.eff","k":"trait","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#EvalFold-91b","e":false,"i":"","n":"EvalFold","t":"EvalFold[A](f: A => Eval[Unit]): RightFold[A, Eval[Unit]]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#IntoMonoidFold-6fe","e":false,"i":"","n":"IntoMonoidFold","t":"IntoMonoidFold[M : Monoid, A](f: A => M): RightFold[A, M]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#ListFold-fffff60a","e":false,"i":"","n":"ListFold","t":"ListFold[A]: RightFold[A, List[A]]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#MonoidFold-fffffd2c","e":false,"i":"","n":"MonoidFold","t":"MonoidFold[A : Monoid]: RightFold[A, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriter-fffff058","e":false,"i":"","n":"runWriter","t":"runWriter[R, U, O, A](w: Eff[R, A])(implicit m: Aux[[_] =>> Writer[O, _$1], R, U]): Eff[U, (A, List[O])]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterEval-b44","e":false,"i":"","n":"runWriterEval","t":"runWriterEval[R, U, O, A](w: Eff[R, A])(f: O => Eval[Unit])(implicit m: Aux[[_] =>> Writer[O, _$8], R, U], ev: MemberIn[Eval, U]): Eff[U, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterFold-ffffff3a","e":false,"i":"","n":"runWriterFold","t":"runWriterFold[R, U, O, A, B](w: Eff[R, A])(fold: RightFold[O, B])(implicit m: Aux[[_] =>> Writer[O, _$2], R, U]): Eff[U, (A, B)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterIntoMonoid-fffff7e6","e":false,"i":"","n":"runWriterIntoMonoid","t":"runWriterIntoMonoid[R, U, O, M, A](w: Eff[R, A])(f: O => M)(implicit m: Aux[[_] =>> Writer[O, _$10], R, U], M: Monoid[M]): Eff[U, (A, M)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterMonoid-b7a","e":false,"i":"","n":"runWriterMonoid","t":"runWriterMonoid[R, U, O, A](w: Eff[R, A])(implicit m: Aux[[_] =>> Writer[O, _$9], R, U], O: Monoid[O]): Eff[U, (A, O)]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation.html#runWriterUnsafe-ffffff25","e":false,"i":"","n":"runWriterUnsafe","t":"runWriterUnsafe[R, U, O, A](w: Eff[R, A])(f: O => Unit)(implicit m: Aux[[_] =>> Writer[O, _$5], R, U]): Eff[U, A]","d":"org.atnos.eff.WriterInterpretation","k":"def","x":""},
{"l":"org/atnos/eff/WriterInterpretation$.html#","e":false,"i":"","n":"WriterInterpretation","t":"WriterInterpretation extends WriterInterpretation","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/writer$.html#","e":false,"i":"","n":"writer","t":"writer extends WriterCreation, WriterInterpretation","d":"org.atnos.eff","k":"object","x":""}];
